AbstractResponse

Trait AbstractResponse 

pub trait AbstractResponse: ModuleIdentification {
    // Provided methods
    fn response(&self, action: impl Into<String>) -> Response { ... }
    fn custom_response(
        &self,
        action: impl Into<String>,
        attributes: impl IntoIterator<Item = impl Into<Attribute>>,
    ) -> Response { ... }
}
Construct a Response with an abstract-specific event. The event contains the contract name and the action, and any additional attributes.

Provided Methods

fn response(&self, action: impl Into<String>) -> Response

Respond with an abstract-specific event that contains the contract name and the action.

fn custom_response( &self, action: impl Into<String>, attributes: impl IntoIterator<Item = impl Into<Attribute>>, ) -> Response

.response() with additional attributes.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors